%% LaTeX document class for Miskolc Mathematical Notes
\def\@mmnver{4.0}
\def\@mmnverdate{26 November 2023}

\def\mmnbibstyle{mmn}

\def\@firstpage{1}

\newcommand\publname{Miskolc Mathematical Notes}

\def\MmN{{\protect$\mathcal{M}$\kern-.1667em\lower.5ex\hbox{$\mathbscr{M}$}\kern-.125em$\mathcal{N}$}}

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{mmn_art}[2023/03/16]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{amsart}}

\DeclareOption{proofs}{\mmndraftwatermarktrue}

\DeclareOption{draftwatermark}{\mmndraftwatermarktrue}

\def\@options{11pt,reqno,twoside}%

\PassOptionsToClass{\@options}{amsart}

\ProcessOptions\relax

\LoadClass{amsart}[1996/10/24]


\def\mypageref#1{\expandafter\@setref\csname r@#1\endcsname
                                   \@secondoftwo{#1}}
\def\mylabel#1{\@bsphack
  \protected@write\@auxout{}%
         {\string\newlabel{#1}{{\@currentlabel}{\thepage}}}%
  \@esphack}

\RequirePackage{textcase}
  
\RequirePackage[utf8x]{inputenc}

\RequirePackage[british]{babel}

\RequirePackage[a4paper,width=130mm,height=190mm,centering]{geometry}

\RequirePackage[noadjust]{cite} 

\RequirePackage{amssymb}

\RequirePackage{latexsym}

\RequirePackage{wasysym}

\RequirePackage{pslatex}

\RequirePackage{amsmath}            

\RequirePackage{mathrsfs}

\RequirePackage{graphicx}

\RequirePackage{lastpage}

\RequirePackage{etoolbox}

\global\def\keywordsname{Keywords}

\def\@setdate{% Manuscript 
Received    \@date% \@addpunct.
}

\renewcommand*\subjclass[2][2010]{%
  \def\@subjclass{#2}%
  \@ifundefined{subjclassname@#1}{%
    \ClassWarning{\@classname}{Unknown edition (#1) of Mathematics
      Subject Classification; using '1991'.}%
  }{%
    \@xp\let\@xp\subjclassname\csname subjclassname@#1\endcsname
  }%
}

%% set subjclass like this:
 \def\@setsubjclass{%
   \ifvoid\subjclassbox
   \else
     \skip@7\p@ \advance\skip@-\lastskip
     \advance\skip@-\baselineskip \vskip\skip@
     \box\subjclassbox
     \prevdepth\z@ % because \abstractbox is a vtop
   \fi
 }

%% set keywords like this:
 \def\@setkeywords{%
   \ifvoid\keywordsbox
   \else
     \skip@3\p@ \advance\skip@-\lastskip
     \advance\skip@-\baselineskip \vskip\skip@
     \box\keywordsbox
     \prevdepth\z@ % because \abstractbox is a vtop
   \fi
 }

%% abstract env
\renewenvironment{abstract}{%
  \ifx\maketitle\relax
    \ClassWarning{\@classname}{Abstract should precede
      \protect\maketitle\space in AMS document classes; reported}%
  \fi
  \global\setbox\abstractbox=\vtop \bgroup
    \normalfont\Small
    \list{}{\labelwidth\z@
%      \leftmargin0pc %\rightmargin\leftmargin
      \leftmargin\parindent \rightmargin\parindent
      \listparindent\normalparindent \itemindent\z@
      \parsep\z@ \@plus\p@
      \let\fullwidthdisplay\relax
    }%
    \item[\noindent\hskip\labelsep\itshape\abstractname.]%
}{%
  \endlist\egroup
  \ifx\@setabstract\relax \@setabstracta \fi
}

%	set PDF meta data (only for the final electronic version)
\newcommand{\pdfmetadata}{}

%setauthors

\def\corresponding{\textbf{Corresponding author}}

\def\@setauthors{%
    \begingroup
    \def\thanks{\protect\thanks@warning}%
    \trivlist
     \centering \footnotesize
    \small \@topsep30\p@\relax \advance\@topsep by -\baselineskip
%
    \item\relax \author@andify\authors \def\\{\protect\linebreak}%
    \MakeUppercase{\authors}%
    \ifx\@empty\contribs \else ,\penalty-3 \space \@setcontribs
    \@closetoccontribs \fi
    \endtrivlist
    \endgroup
}


% first page style 
\def\ps@firstpage{\ps@empty
  \def\@oddfoot{% \normalfont\scriptsize \hfil\thepage\hfil
%      \global\topskip\normaltopskip
   }%
  \let\@evenfoot\@oddfoot
   
  \def\@oddhead{\@serieslogo\hss}%
  \let\@evenhead\@oddhead % in case an article starts on a left-hand page
}


\def\maketitle{\par
  \@topnum\z@ % this prevents figures from falling at the top of page 1
   \@setcopyright
  \thispagestyle{firstpage}% this sets first page specifications
  \ifx\@empty\shortauthors \let\shortauthors\MakeTextUppercase\shorttitle
  \else \andify\shortauthors
  \fi
  \@maketitle@hook
  \begingroup
  \@maketitle
  \toks@\@xp{\shortauthors}\@temptokena\@xp{\MakeTextUppercase\shorttitle}%
  \toks4{\def\\{ \ignorespaces}}% defend against questionable usage
  \edef\@tempa{%
    \@nx\markboth{\the\toks4
      \@nx\MakeUppercase{\the\toks@}}{\the\@temptokena}}%
  \@tempa
  \endgroup
  \c@footnote\z@
  \@cleartopmattertags
}

% maketitle ****************************************************
\def\@maketitle{%
%\thispagestyle{empty}
  \newbox\subjclassbox
  \newbox\keywordsbox
  %%\global\def\subjclassname{Mathematics Subject Classification}
% box for subjclass
  \global\setbox\subjclassbox=\vtop \bgroup
     \normalfont\Small
     \list{}{\labelwidth\z@
%       \leftmargin3pc \rightmargin\leftmargin
       \leftmargin\parindent \rightmargin0pc
       \listparindent\normalparindent \itemindent\z@
       \parsep\z@ \@plus\p@
       \let\fullwidthdisplay\relax
     }%
     \item[\noindent\hskip\labelsep{\itshape\subjclassname:}]%
       \@subjclass
     {\endlist\egroup %
     }
% box for keywords
  \global\setbox\keywordsbox=\vtop \bgroup
     \normalfont\Small
     \list{}{\labelwidth\z@
       \leftmargin\parindent \rightmargin\leftmargin
%      \leftmargin\parindent \rightmargin0pc
       \listparindent\normalparindent \itemindent\z@
       \parsep\z@ \@plus\p@
       \let\fullwidthdisplay\relax
     }%
     \item[\noindent\hskip\labelsep{\itshape\keywordsname:}]%
       \@keywords
     {\endlist\egroup %
     }
% now setting the rest
   \normalfont\normalsize
   \let\@makefnmark\relax  \let\@thefnmark\relax
   \ifx\@empty\thankses\else \@footnotetext{%
     \def\par{\let\par\@par}\@setthanks}\fi
   \@mkboth{\@nx\shortauthors}{\@nx\shorttitle}%
 \global\topskip42\p@% 5.5 picas to the base of the first title line
%  \bigskip\bigskip %%%%% Saturday, November 10 2007
   \centering\@settitle 
    \ifx\@empty\authors\relax\else\@setauthors\fi
%   \@message{The authors have been set up}
  % \ifx\@empty\addresses \else\@setaddresses\fi
   \ifx\@empty\@dedicatory\relax
   \else
     \baselineskip18\p@
     \vtop{% \centering
       {\noindent\footnotesize\itshape\@dedicatory\@@par}%
       \global\dimen@i\prevdepth}\prevdepth\dimen@i
   \fi
%    \ifx\@empty\@date\relax
%    \else
%    {\noindent\footnotesize\itshape\@setdate}
%    \fi
	{\noindent\footnotesize\itshape\@setdate}
   \@setabstract
   \ifx\@empty\@subjclass\relax\else {\@setsubjclass}\fi
    \ifx\@empty\@keywords\relax\else {\@setkeywords}\fi
% %
   \normalsize
   \dimen@34\p@ \advance\dimen@-\baselineskip
   \vskip\dimen@\relax
% for contents
%\andify\ttlauthors
\def\\{\protect\linebreak}%
%%%%
 \def\@ppp{\@firstpage}%

 } % end \@maketitle

% section-like things to manage, e.g., the author marks
\def\@starthiddensection#1#2#3#4#5#6{%
 \if@noskipsec \leavevmode \fi
 \par \@tempskipa #4\relax
 \@afterindenttrue
 \ifdim \@tempskipa <\z@ \@tempskipa -\@tempskipa \@afterindentfalse\fi
 \if@nobreak \everypar{}\else
     \addpenalty\@secpenalty\addvspace\@tempskipa\fi
 \@ifstar{\@dblarg{\@hiddensect{#1}{\@m}{#3}{#4}{#5}{#6}}}%
         {\@dblarg{\@hiddensect{#1}{#2}{#3}{#4}{#5}{#6}}}%
}

\def\@hiddensect#1#2#3#4#5#6[#7]#8{%
  \edef\@toclevel{\ifnum#2=\@m 0\else\number#2\fi}%
  \ifnum #2>\c@secnumdepth \let\@secnumber\@empty
  \else \@xp\let\@xp\@secnumber\csname the#1\endcsname\fi
  \@tempskipa #5\relax
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \edef\@secnumpunct{%
      \ifdim\@tempskipa>\z@ % not a run-in section heading
        \@ifnotempty{#8}{.\@nx\enspace}%
      \else .\@nx\enspace
      \fi
    }%
    \protected@edef\@svsec{%
      \ifnum#2<\@m
        \@ifundefined{#1name}{}{%
          \ignorespaces\csname #1name\endcsname\space
        }%
      \fi
      \@seccntformat{#1}%
    }%
  \fi
  \ifdim \@tempskipa>\z@ % then this is not a run-in section heading
    \begingroup #6\relax
    \@hangfrom{\hskip #3\relax\@svsec}{\interlinepenalty\@M #8\par}%
    \endgroup
    \ifnum#2>\@m \else %%%\@tocwrite{#1}{#8}
  \fi
  \else
  \def\@svsechd{#6\hskip #3\@svsec
    \@ifnotempty{#8}{\ignorespaces#8\unskip
%        \@addpunct.
     }%
    \ifnum#2>\@m \else %%%\@tocwrite{#1}{#8}
  \fi
  }%
  \fi
  \global\@nobreaktrue
  \@xsect{#5}}

\def\hiddensection{\@starthiddensection{section}{1}%
  \z@{.7\linespacing\@plus\linespacing}{.5\linespacing}%
  {\indent\normalfont\itshape}} 
%%  {\centering\normalfont\scshape}} %%Thursday, October 09 2008

\def\acknowledgementsection{\@starthiddensection{section}{1}%
  \z@{.7\linespacing\@plus\linespacing}{.5\linespacing}%
  {\centering\normalfont\scshape}}

\def\hiddensubsection{\@starthiddensection{subsection}{2}%
  \z@{.5\linespacing\@plus.7\linespacing}{-.5em}%
  {\indent\normalfont\bfseries}}

% setaddresses
 \def\@setaddresses{\par
 	\ifnum\authorcount=1
         \def\addr@cap{Author's address}
    \else
         \def\addr@cap{Authors' addresses}
	\fi
	\nobreak
	\begingroup
		\@xp\hiddensection\@xp*\@xp{\noindent\small{\addr@cap}}% kedd, december 04 2007
		\footnotesize
		\def\author##1{\nobreak\addvspace\bigskipamount}%
		\def\\{\unskip, \ignorespaces}%
		\interlinepenalty\@M
		\def\address##1##2{
			\begingroup
	     		\par\addvspace\bigskipamount\indent\indent
	    		 \@ifnotempty{##1}{(\ignorespaces##1\unskip) }%
	     		{\upshape\ignorespaces##2}\par
	     	\endgroup
		}%
		\def\curraddr##1##2{
			\begingroup
				\@ifnotempty{##2}{\nobreak\indent{\itshape Current address}%
				\@ifnotempty{##1}{, \ignorespaces##1\unskip}\/:\space##2\par}
			\endgroup
		}%
	   \def\email##1##2{
			\begingroup
	%      \@ifnotempty{##2}{\nobreak\indent{\itshape E-mail address}%
	%        \@ifnotempty{##1}{, \ignorespaces##1\unskip}\/:\space
				\@ifnotempty{##2}{\nobreak\indent{\itshape E-mail address:}%
				\@ifnotempty{##1}{ \ignorespaces##1\unskip}\/\space\upshape\ttfamily##2\par}
			\endgroup
		}%
		\def\urladdr##1##2{
			\begingroup
				\@ifnotempty{##2}{\nobreak\indent{\itshape URL}%
				\@ifnotempty{##1}{, \ignorespaces##1\unskip}\/:\space\upshape\tt##2\par}
			\endgroup
		}%
	   \addresses
   \endgroup
}

\def\@setcopyright{%
  \ifx\@empty\@serieslogo
  \else\ifx\@empty\copyrightyear
  \else
    \insert\copyins{\hsize\textwidth
%      \parfillskip\z@\relax
%      \leftskip\z@\@minus0.9\textwidth\relax
      \rightskip\z@\relax
      \@copyinsfontsize
      \everypar{}%
      \vskip-\skip\copyins
      \if@extracrline
        \vskip-6pt
      \fi
      \nointerlineskip
      \leavevmode\hfill\vrule\@width\z@\@height\skip\copyins
\hfill
{ 
%%%
\fontsize{8}{7\p@}\normalfont%\scshape
%%% \hfill % Copyright
\vspace{\baselineskip}
\\ \noindent\rule{0.165\textwidth}{0.4pt}\newline
\copyright\ 20??\ The Author(s). Published by Miskolc University Press.\ This is an open access article under the license \href{http://creativecommons.org/licenses/by/4.0/}{CC BY 4.0}.\ignorespaces
}
      \if@extracrline \@extracrline \fi
      \par
      \kern\z@}%
  \fi\fi
}

\def\@logofont{\small}

%%logo
\long\def\set@logo#1{%
   \vbox to\headheight{%
     \@parboxrestore %\fontsize{9}{7\p@}\selectfont
\@logofont
\noindent #1\par\vss
   }%
}

\def\article@logo{%
\set@logo{%
\def\@logofirstline{\@logofont{\publname}%\/,\ 
\hfill HU e-ISSN 1787-2413
\newline Vol.~{??} (20??), No.~?, pp.~\@firstpage--xx\hfill DOI: 10.18514/MMN.20??.????}
\def\@logolines{\@logofont\@logofirstline}


%\def\article@logo{%
%	\set@logo{%
%		\def\@logofirstline{\@logofont{\publname}%\/,\ 
%			\hfill\@ISSNname\ \@ISSN%\ (\@publtype)
%			\newline Vol.~{\mmnvolume} (\mmnyear), No.~\mmnnumber, pp.~\@firstpage--\@lastpage\hfill DOI: 10.18514/MMN.\mmnyear.\articlenumber}
%		\def\@logolines{\@logofont\@logofirstline}
		

\newlength{\@logowidth}\setlength{\@logowidth}{\linewidth}%%\settowidth{\@logowidth}{\@logofirstline}
\newlength{\@logoheight}\settowidth{\@logoheight}{\@logolines}

\addtolength{\@logowidth}{-17mm}

%\noindent\includegraphics[height=20pt,keepaspectratio]{blazon}\,
\def\@logosuff{_bw}
%\def\@logosuff{_c}
%\noindent\includegraphics[height=33pt,keepaspectratio]{me_logo_small\@logosuff}\,
\noindent\includegraphics[height=30pt,keepaspectratio]{Logo_ME}\,
%\noindent\includegraphics[height=33pt,keepaspectratio]{mnotes_blarge}\,
\parbox[b]{\@logowidth}{\vspace*{-5mm}\@logolines%
\vskip .6\baselineskip% 
%\hrule\hrule
   } 
  }
}

%%  --- now programming the stuff...

\makeatletter

%\countdef\@infile=8
\newread\@infile
\newwrite\@outfile
%\countdef\@outfile=7

\AtBeginDocument{%
\let\emptyset\varnothing %%% because of fourier!

\newcount\authorcount
 \authorcount0

} %AtBegin

\AtEndDocument{\mylabel{last:\jobname}
\addtocounter{page}{-1}

}
\def\addr@markup{}

\renewcommand*{\title}[2][]{\gdef\shorttitle{\unexpanded{#1}}\gdef\@title{\unexpanded{#2}}}
\edef\title{\@nx\@dblarg
  \@xp\@nx\csname\string\title\endcsname}

\renewcommand{\author}[2][]{%
  \ifx\@empty\authors
    \gdef\authors{#2}%
  \else
    \g@addto@macro\authors{\and#2}%
    \g@addto@macro\addresses{\author{}}%
  \fi
%
%
  \@ifnotempty{#1}{%
    \ifx\@empty\shortauthors
      \gdef\shortauthors{\unexpanded{#1}}%
    \else
      \g@addto@macro\shortauthors{\and\unexpanded{#1}}%
    \fi
  }%

  \g@addto@macro\addresses{\@xp\hiddensubsection\@xp*\@xp{#2\newline}}%
  \advance\authorcount by 1
  
}
\edef\author{\@nx\@dblarg
  \@xp\@nx\csname\string\author\endcsname}

%authors

% sections

\def\appendix{\par\c@section\z@ \c@subsection\z@
   \let\sectionname\appendixname
   \def\thesection{\@Alph\c@section}}
\def\appendixname{Appendix}

 \def\section{\def\@secnumfont{% \bfseries
   }%
 \@startsection{section}{1}%
     \z@{.7\linespacing\@plus\linespacing}{.5\linespacing}%
     {\centering\normalfont\normalsize% \bfseries
       \scshape% \boldmath
     }} %% "\boldmath"
                                 %% added 21 Oct 2003
                                 
\def\subsection{ \def\@secnumfont{}%
\@startsection{subsection}{2}%
  \z@{.5\linespacing\@plus.5\linespacing}%%{-.5em}
{.5\linespacing}%
  {\indent\normalfont\normalsize\itshape}}

\def\subsubsection{ \def\@secnumfont{}%
\@startsection{subsubsection}{3}%
  \z@{.5\linespacing\@plus.5\linespacing}%%{-.5em}
{.5\linespacing}%
  {\indent\normalfont\normalsize\itshape}}

\def\@settitle{\baselineskip14\p@\relax
{\larger\bfseries\MakeTextUppercase\@title}%
} %------


%indenting 1st pars
\let\@afterindentfalse\@afterindenttrue
\@afterindenttrue

%%%

%%18 august 2004--
\renewcommand{\qedsymbol}{\textsquare}%
%\renewcommand{\qedsymbol}{\SquareShadowB}% %% ifsym is needed here
\renewenvironment{proof}[1][\proofname]{\par
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\indent\hskip\labelsep
        \itshape
    #1\@addpunct{.}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}

%%
\def\th@remark{%
  \thm@headfont{\itshape}%
  \let\thm@indent\indent
  \normalfont % body font
}%%

\def\th@plain{%
  \let\thm@indent\indent % 
  \thm@headfont{\bfseries}% heading font is bold
\thm@notefont{\normalfont}% same as heading font
  \thm@headpunct{.}% add period after heading
  \itshape % body font
}%%

\def\th@definition{%
    \thm@headfont{\bfseries}%
  \let\thm@indent\indent
  \normalfont % body font
}
%%%
\newenvironment{none}[1][]{\par
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\indent\hskip\labelsep
        \normalfont
    #1%\@addpunct{.}
]\ignorespaces
}{%
%  \popQED
\endtrivlist\@endpefalse
}


\newenvironment{mmnlist}[1][]{\par
  \normalfont 
  \trivlist
  \item[\indent\hskip\labelsep
        \normalfont
    #1 
]\ignorespaces
}{%
%  \popQED
\endtrivlist\@endpefalse
}

\def\pointitemfont{\itshape}
\newcounter{pointitem} 
\newenvironment{point}[1][\empty]{\setcounter{pointitem}{0} 
\topsep6\p@\@plus6\p@\relax

\setlength{\leftmargini}{0pt}%

\ifx#1\empty%
\def\pitem{\ifhmode\else\parskip\parsep\fi%
\addtocounter{pointitem}{1}(\thepointitem)\space}%
\else%
\def\pitem{\ifhmode\else\medskip\fi%
\addtocounter{pointitem}{1}{\pointitemfont #1}\ \thepointitem.\space}%
\fi%
}{}

\def\odditemfont{\scshape}
\newcommand{\odditem}[2][]{\ifvmode\smallskip\fi{\odditemfont #1\ #2.}}

\def\acknowledgementfont{\normalsize}

\def\acknowledgementname{Acknowledgements}
\newenvironment{acknowledgement}[1][\acknowledgementname]{\acknowledgementsection*{\acknowledgementfont#1}\acknowledgementfont}{}


\usepackage[colorlinks=true,bookmarks=true]{hyperref}

\newcount\@page@check

\newcommand{\alert}[1]{}%
\newcommand{\alerted}[2]{#1}% 

\providecommand{\cyr}{}

\makeatletter
\def\aliasbib#1#2{\expandafter\xdef
\csname b@#1\endcsname{\csname b@#2\endcsname}}
\makeatother


\endinput
